Pre-configured Packs
====================

The OU Container Builder provides a number of pre-configured packs that can be :doc:`enabled in the configuration <../configuration/packs>`.
The following built-in packs are available:

.. toctree::
    :maxdepth: 1

    code-server
    nbclassic
    jupyterlab
    mariadb
    tutorial_server
